<?php

#
# WordPress Trainingstagebuch plugin
# Copyright (C) 2009 Christian Schenk
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#


/**
 * Gibt Trainingsuebersicht aus.
 */
function get_exercise_summary($xml, $show = array()) {
	$rVal = '<div class="tb_exercise_summary">'.
	        '<span class="heading">'.__('Summe aller Trainingseinheiten', 'trainingstagebuch').'</span>'.
	        '<table>';

	if (!empty($xml->count) and !empty($show['summary_count'])) {
		$rVal .= '<tr class="count">'.
		         '<td>'.__('Trainingseinheiten', 'trainingstagebuch').':</td>'.
		         '<td>'.$xml->count.'</td>'.
		         '</tr>';
	}

	if (!empty($show['summary_duration'])) {
		$rVal .= '<tr class="duration">'.
		         '<td>'.__('Zeit', 'trainingstagebuch').':</td>'.
		         '<td>'.$xml->duration.' '.__('Stunden', 'trainingstagebuch').'</td>'.
		         '</tr>';
	}

	if (!empty($show['summary_distance'])) {
		$rVal .= '<tr>'.
		         '<td>'.__('Kilometer', 'trainingstagebuch').':</td>'.
		         '<td>'.$xml->{'distance-km'}.' km</td>'.
		         '</tr>';
	}

	$rVal .= '</table>'.
	         '</div>';

	return $rVal;
}


/**
 * Gibt Trainingseinheiten aus.
 */
function get_exercises($xml, $show = array(), $start = NULL, $end = NULL) {
	if (count($xml->exercise) == 0) return '';

	$rVal = '<div class="tb_exercises"><table>';

	$i = 0;
	foreach($xml->exercise as $exercise) {
		$i++;

		if ($start != NULL and $start > $i) continue;
		if ($end != NULL and $end < $i) continue;

		$rVal .= '<tr>';

		if (!empty($show['number'])) {
			$rVal .= '<th>'.$i.'</th>';
		}

    	// Link zur Einheit
		if (!empty($show['date'])) {
    		$rVal .= '<td><a href="http://trainingstagebuch.org/public/show/' . $exercise->id .'">';
			$rVal .= trainingstagebuch_convert_date($exercise->date);
			$rVal .= '</a></td>';
		}

		// Trainingsdauer
		if (!empty($show['duration'])) {
			$rVal .= "<td>$exercise->duration Std.</td>";
		}

		// Herzfrequenz (Dschn.) / Herzfrequenz (Max.)
		if (!empty($show['heartrate'])) {
			if ($exercise->{'heartrate-avg'} > 1) {
				$rVal .= '<td>' . $exercise->{'heartrate-avg'} . ' / ' . $exercise->{'heartrate-max'} . ' bpm</td>';
			} else {
				$rVal .= '<td></td>';
			}
		}

		// Geschwindigkeit (Dschn.) / Geschwindigkeit (Max.)
		if (!empty($show['speed'])) {
			if ($exercise->{'speed-avg'} > 1) {
				$rVal .= '<td>' . $exercise->{'speed-avg'} . '  / ' . $exercise->{'speed-max'} . ' km/h</td>';
			} else {
				$rVal .= '<td></td>';
			}
		}
    
		// Trainingsbereich
		#$rVal .= '<td bgcolor="' . $exercise->{'zone-color'} . '">' . $exercise->{'zone-name'} . '</td>';
    
		// Trainingsgefuehl (BORG)
		if (!empty($show['borg'])) {
			if ($exercise->{'borg-id'} >= 1) {
				$borgImg = $exercise->{'borg-image'};
				if (get_option(OPTION_TRAININGSTAGEBUCH_BORG_IMAGE) == 'small') $borgImg = str_replace('borg', 'borg/small', $borgImg);
				$rVal .= '<td><img src="http://trainingstagebuch.org/static' . $borgImg . '"></td>';
			} else {
				$rVal .= '<td></td>';
			}
		}

		$rVal .= '</tr>';
	}
	$rVal .= '</table></div>';

	return $rVal;
}


/**
 * Datum YYYY-MM-DD in TT.MM.YYYY umwandeln
 */
function trainingstagebuch_convert_date($date) {
	$datum = explode ('-', $date);
	return $datum[2].'.'.$datum[1].'.'.$datum[0];
}


/**
 * Gibt JavaScript fuer die grafische Auswertung des Trainings aus, damit das
 * Flash angezeigt wird.
 */
function get_graph($id, $type) {
	if (in_array($type, array('hfpie', 'hf', 'workout')) == false)
		return '';

	$url = 'http://trainingstagebuch.org';
	$param = array();
	switch ($type) {
	case 'hfpie':
		$param = array('type' => 'ampie', 'size' => 350,
		               'settings' => $url.'/static/charts/settings/hrzones.xml?v2',
		               'data' => $url.'/file/hrzones/'.$id,
		               'write' => 'hrzones');
		break;
	case 'hf':
		$param = array('type' => 'amline', 'size' => 350,
		               'settings' => $url.'/static/charts/settings/maxbpm.xml?v1',
		               'data' => $url.'/file/maxbpm/'.$id,
		               'write' => 'maxbpm');
		break;
	case 'workout':
		$param = array('type' => 'amline', 'size' => 500,
		               'settings' => $url.'/static/charts/settings/file.xml?v1',
		               'data' => $url.'/file/chart/'.$id.'?view=chart',
		               'write' => 'flashcontent');
		break;
	}

	$rVal = '<script type="text/javascript" src="'.$url.'/static/js/swfobject.js"></script>';
	$rVal .= '<script type="text/javascript">
//<![CDATA[
<!--
	var so = new SWFObject("'.$url.'/static/charts/'.$param['type'].'/'.$param['type'].'.swf", "'.$param['type'].'", "98%", "'.$param['size'].'", "8", "#FFFFFF");
	so.addVariable("path", "'.$url.'/static/charts/'.$param['type'].'/");
	so.addVariable("settings_file", escape("'.$param['settings'].'"));
	so.addVariable("data_file", escape("'.$param['data'].'"));
	so.addVariable("loading_settings", "Lade ...");
	so.addVariable("loading_data", "Lade ...");
	so.addVariable("preloader_color", "#999999");
	so.write("'.$param['write'].'");
//-->
//]]>
</script>';

	return $rVal;
}

?>
